// Copyright 2011 Thomas Kamps anubis1@linux-ecke.de
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

#include "bookmark.h"
#include <QHBoxLayout>

Bookmark::Bookmark(QIcon icon, QString url, QString title, QObject *parent) : QWidgetAction(parent) {
	m_url = url;
	m_title = title;
	deleteMe = false;

	setIcon(icon);

	m_button = new QPushButton(0);
	m_button->setText(m_title);
	m_button->setFlat(true);
	m_button->setIcon(icon);
	m_button->setStyleSheet("text-align:left");

	m_bDelete = new QPushButton(0);
	m_bDelete->setText("");
	m_bDelete->setFlat(true);
	m_bDelete->setIcon(QIcon(":/icons/stop.png"));
	m_bDelete->setMinimumSize(16,16);
	m_bDelete->setMaximumSize(16,16);


	this->setDefaultWidget(new QWidget());
	this->defaultWidget()->setLayout(new QHBoxLayout());
	defaultWidget()->layout()->addWidget(m_button);
	defaultWidget()->layout()->addWidget(m_bDelete);

	connect(m_button, SIGNAL(clicked()), this, SLOT(trigger()));
	connect(m_button, SIGNAL(clicked()), this, SIGNAL(triggered()));
	connect(m_bDelete, SIGNAL(clicked()), this, SLOT(deleteIt()));
	connect(m_bDelete, SIGNAL(clicked()), this, SIGNAL(triggered()));
}

Bookmark::~Bookmark() {
	this->defaultWidget()->layout()->removeWidget(m_button);
	this->defaultWidget()->layout()->removeWidget(m_bDelete);

	m_button->deleteLater();
	m_bDelete->deleteLater();
}
