// Copyright 2011 Thomas Kamps anubis1@linux-ecke.de
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

#ifndef BROWSERTAB_H
#define BROWSERTAB_H

#include <QObject>
#include <QToolButton>
#include <QMenu>
#include <QVBoxLayout>
#include <QLineEdit>
#include <QLabel>
#include <QWebView>

#include "webview.h"

class BrowserTab : public QObject {
	Q_OBJECT

	public:
		explicit BrowserTab(QObject *parent = 0);
		~BrowserTab();
		bool isEmptyPage();
		WebView* getView() { return view; }

		QWidget* content;
		QToolButton* tabButton;

	signals:
		void selected(BrowserTab* tab);
		void closed(BrowserTab* tab);

		void newTab(QString url);
		void bookmark(QString title, QString url, QIcon icon);
		void newWindow(QWebView** view);

	public slots:
		void back();
		void forward();
		void stop();
		void reload();

		void showTab();

		void goTo(QString url, bool hideUrlBar=true);

	private slots:
		//Signal handler
		void loadUrl(); //Load the url from urlBar
		void setTitle(QString title); //Sets the title
		void setIcon(); //Sets the icon
		void showUrl(QUrl url); //Sets the urlBar's test to the given url
		void updateHoverUrl(QString url); //Updates the currently hoverd url
		void setSSLError(); //Sets an SSLError

		void showUrlBar(); //Shows the urlBar

		//signal emitter
		void closeTab();
		void openNewTab();
		void newBookmark();

	private:
		void setSSL(bool sslUsed);

		//Webview items
		QVBoxLayout* layout;
		QLineEdit* urlBar;
		WebView* view;
		QLabel* lHoverUrl;

		//Menu items
		QMenu* menu;
		QAction* acShow;
		QAction* acBookmark;
		QAction* acEditUrl;
		QAction* acClose;

		//other stuff
		QMenu* contextMenu;
		QString curHoverUrl;

		//SSL-Settings
		bool ssl;
		bool sslOk;
};

#endif // BROWSERTAB_H
