// Copyright 2011 Thomas Kamps anubis1@linux-ecke.de
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

#include "webview.h"

#include <QSemaphore>
#include "dialogs/passworddialog.h"

WebView::WebView(QWidget *parent) : QWebView(parent) {
	curHoverUrl = QString();
	connect(page(), SIGNAL(linkHovered(QString,QString,QString)), this, SLOT(updateCurHoverUrl(QString)));
	connect(page()->networkAccessManager(), SIGNAL(authenticationRequired(QNetworkReply*,QAuthenticator*)), this, SLOT(getAuthentication(QNetworkReply*, QAuthenticator*)));
}

QWebView* WebView::createWindow(QWebPage::WebWindowType type) {
	Q_UNUSED(type);

	QWebView* view;
	emit(newWindow(&view));
	return view;
}

void WebView::mousePressEvent(QMouseEvent *e) {
	if (e->button() == Qt::MidButton) {
		if (curHoverUrl.isNull()) return;
		QWebView* view = createWindow(QWebPage::WebBrowserWindow);
		view->load(QUrl(curHoverUrl));
	}
	else QWebView::mousePressEvent(e);
}

void WebView::updateCurHoverUrl(QString url) {
	curHoverUrl = url;
}

void WebView::getAuthentication(QNetworkReply* repl, QAuthenticator *auth) {
	Q_UNUSED(repl);

	PasswordDialog d(auth, 0);
	d.exec();
	//sem.acquire(1);
}
